Interface: ScaleTypeRegistry | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ScaleTypeRegistry

## # Hierarchy

- `CartesianScaleTypeRegistry`

- `RadialScaleTypeRegistry`

  ↳ `ScaleTypeRegistry`

## # Properties

### # category

• category: `Object`

#### # Type declaration

Name | Type
--- | ---
`options` | `CategoryScaleOptions`

#### # Inherited from

CartesianScaleTypeRegistry.category

#### # Defined in

index.esm.d.ts:3491
(opens new window)

### # linear

• linear: `Object`

#### # Type declaration

Name | Type
--- | ---
`options` | `LinearScaleOptions`

#### # Inherited from

CartesianScaleTypeRegistry.linear

#### # Defined in

index.esm.d.ts:3485
(opens new window)

### # logarithmic

• logarithmic: `Object`

#### # Type declaration

Name | Type
--- | ---
`options` | `LogarithmicScaleOptions`

#### # Inherited from

CartesianScaleTypeRegistry.logarithmic

#### # Defined in

index.esm.d.ts:3488
(opens new window)

### # radialLinear

• radialLinear: `Object`

#### # Type declaration

Name | Type
--- | ---
`options` | `RadialLinearScaleOptions`

#### # Inherited from

RadialScaleTypeRegistry.radialLinear

#### # Defined in

index.esm.d.ts:3503
(opens new window)

### # time

• time: `Object`

#### # Type declaration

Name | Type
--- | ---
`options` | `TimeScaleOptions`

#### # Inherited from

CartesianScaleTypeRegistry.time

#### # Defined in

index.esm.d.ts:3494
(opens new window)

### # timeseries

• timeseries: `Object`

#### # Type declaration

Name | Type
--- | ---
`options` | `TimeScaleOptions`

#### # Inherited from

CartesianScaleTypeRegistry.timeseries

#### # Defined in

index.esm.d.ts:3497
(opens new window)